@@ -554,7 +554,7 @@ class CythonConstraintGenerator(PredGenerator):
         out.writeln("cdef class ApiSpace(ProtoSpace):")
         out.newline()
         for name,dtree in self.dtrees.items():
-            vars = ("x%d" % (i+1) for i in range(dtree.numargs-1))
+            vars = tuple("x%d" % (i+1) for i in range(dtree.numargs-1))
             parms = ("%s=None" % v for v in vars)
             out.indent_to(indent+4)
             if name in ("min","max"):
@@ -562,6 +562,9 @@ class CythonConstraintGenerator(PredGenerator):
                 # an IntVar's domain; so rename
                 name = "_%s" % name
             out.writeln("def %s(self,%s):" % (name,",".join(parms)))
+            for v in vars:
+                out.indent_to(indent+8)
+                out.writeln("%s = normalize_parameter(%s)" % (v,v))
             dtree.generate(vars, out, indent+8)
             out.newline()
 
